@@ -468,10 +468,10 @@ static void do_sub(char *cmd, int global, int subnode)
 		if (eopat[0] - bopat[0] != slen) {
 			int mlen = end - eopat[0]+1;
 			if (mlen > 0)
-				memmove(bopat[0] + slen, eopat[0], mlen);
+				memmove((char *)bopat[0] + slen, eopat[0], mlen);
 		}
-		memcpy(bopat[0], csub, slen);
-		start = bopat[0] + slen;
+		memcpy((char *)bopat[0], csub, slen);
+		start = (char *)bopat[0] + slen;
 	} while(global);
 
 	generator_emit_string(buff);
