@@ -167,7 +167,7 @@ int main(int argc, char *argv[])
 	rnd_app.expose_main = camv_expose_main;
 	rnd_app.expose_preview = camv_expose_preview;
 
-	rnd_app.dot_dir = CONF_USER_DIR;
+	rnd_app.dot_dir = DOT_CAMV_RND;
 	rnd_app.lib_dir = LIBDIR;
 
 	rnd_fix_locale_and_env();
