@@ -1,4 +1,5 @@
-conf_reg(appearance.default_font,             scalar, RND_CFN_STRING,  "appearance",             "default_font",           "path to the ttf of the default font", 0)
+conf_reg(appearance.default_font,             scalar, RND_CFN_STRING,  "appearance",             "default_font",           "OBSOLETE: used to be path to a ttf font; camv-rnd uses an embedded internal vector font now", 0)
+conf_reg(appearance.bbox_debug,               scalar, RND_CFN_BOOLEAN, "appearance",             "bbox_debug",             "enable rendering bounding box of objects, for debugging", 0)
 conf_reg(appearance.color.layer,              array,  RND_CFN_COLOR,   "appearance/color",       "layer",                  "default layer colors; when a new layer is created, a color from this list is assigned initially", 0)
 conf_reg(appearance.color.attached,           scalar, RND_CFN_COLOR,   "appearance/color",       "attached",               "<attached>", 0)
 conf_reg(rc.error_on_bad_cli_files,           scalar, RND_CFN_BOOLEAN, "rc",                     "error_on_bad_cli_files", "<error_on_bad_cli_files>", 0)
