@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  camv-rnd - electronics-related CAM viewer
- *  Copyright (C) 2019,2023 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2023,2024 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -106,6 +106,7 @@ void camv_draw_layer(camv_layer_t *ly, rnd_hid_gc_t gc, const rnd_hid_expose_ctx
 }
 
 rnd_cardinal_t camv_draw_inhibit = 0;
+rnd_box_t camv_last_main_expose_region;
 
 void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
 {
@@ -117,6 +118,11 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 	if (camv_draw_inhibit)
 		return;
 
+	camv_last_main_expose_region.X1 = region->view.X1;
+	camv_last_main_expose_region.Y1 = region->view.Y1;
+	camv_last_main_expose_region.X2 = region->view.X2;
+	camv_last_main_expose_region.Y2 = region->view.Y2;
+
 	if ((rnd_render != NULL) && (!rnd_render->override_render))
 		rnd_render = hid;
 
@@ -154,6 +160,11 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 		}
 
 		if (((int)ly->clearing != clearing) || (!ly->sub)) {
+			if (ly->prefill) {
+				rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, direct, &region->view);
+				rnd_render->set_color(gc, &ly->color);
+				rnd_render->fill_rect(gc, region->view.X1, region->view.Y1, region->view.X2, region->view.Y2);
+			}
 			clearing = ly->clearing;
 			rnd_render->set_drawing_mode(rnd_render, ly->clearing ? RND_HID_COMP_NEGATIVE : RND_HID_COMP_POSITIVE, direct, &region->view);
 		}
@@ -174,5 +185,14 @@ void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xf
 
 void camv_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e)
 {
+	rnd_hid_gc_t gc = rnd_render->make_gc(rnd_render);
 
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_RESET, 1, &e->view);
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, 1, &e->view);
+	e->expose_cb(gc, e);
+	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_FLUSH, 1, &e->view);
+	rnd_render->end_layer(rnd_render);
+	rnd_render->render_burst(rnd_render, RND_HID_BURST_END, &e->view);
+
+	rnd_render->destroy_gc(gc);
 }
