@@ -29,7 +29,8 @@
 
 static const char *camv_evnames[] = {
 	"camvev_layers_changed",
-	"camvev_layervis_changed"
+	"camvev_layervis_changed",
+	"camvev_layer_selected"
 };
 
 void camv_event_init_app(void)
