@@ -29,10 +29,14 @@
 
 #include <librnd/core/event.h>
 
+/* Prefix:
+   [d]: per-design: generated for a specific rnd_design_t
+   [a]: per-app: generated once, not targeted or specific for a rnd_design_t
+*/
 enum {
-	CAMV_EVENT_LAYERS_CHANGED = RND_EVENT_app,   /* called after layers or layer groups change (used to be the LayersChanged action) */
-	CAMV_EVENT_LAYERVIS_CHANGED,                 /* called after the visibility of layers has changed */
-	CAMV_EVENT_LAYER_SELECTED,                   /* called when a new layer is selected; args: int layer_id */
+	CAMV_EVENT_LAYERS_CHANGED = RND_EVENT_app,   /* [d] called after layers or layer groups change (used to be the LayersChanged action) */
+	CAMV_EVENT_LAYERVIS_CHANGED,                 /* [d] called after the visibility of layers has changed */
+	CAMV_EVENT_LAYER_SELECTED,                   /* [d] called when a new layer is selected; args: int layer_id */
 	CAMV_EVENT_last                              /* not a real event */
 };
 
