@@ -48,17 +48,25 @@
 
 #include "dlg_about.h"
 #include "dlg_layer.h"
+#include "dlg_viewport.h"
 
 static const char *camv_dialogs_cookie = "camv_dialogs";
 
 void camv_dialogs_layer_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	camv_layer_dlg_layer_chg_ev(hidlib, user_data, argc, argv);
+	camv_dlg_viewport_redraw_all();
+}
+
+void camv_dialogs_layervis_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+{
+	camv_dlg_viewport_redraw_all();
 }
 
 void camv_dialogs_layer_selected_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	camv_layer_dlg_layer_chg_ev(hidlib, user_data, argc, argv);
+	camv_dlg_viewport_redraw_all();
 }
 
 
@@ -67,7 +75,8 @@ static rnd_action_t camv_dialogs_action_list[] = {
 	{"PrintGUI", rnd_act_PrintDialog, rnd_acth_PrintDialog, rnd_acts_PrintDialog},
 #endif
 	{"About", camv_act_About, camv_acth_About, camv_acts_About},
-	{"LayerDialog", camv_act_LayerDialog, camv_acth_LayerDialog, camv_acts_LayerDialog}
+	{"LayerDialog", camv_act_LayerDialog, camv_acth_LayerDialog, camv_acts_LayerDialog},
+	{"ViewPortDialog", camv_act_ViewPortDialog, camv_acth_ViewPortDialog, camv_acts_ViewPortDialog}
 };
 
 extern int camv_dlg_pref_tab;
@@ -80,6 +89,7 @@ void pplg_uninit_dialogs(void)
 	rnd_event_unbind_allcookie(camv_dialogs_cookie);
 	rnd_remove_actions_by_cookie(camv_dialogs_cookie);
 	rnd_dlg_pref_uninit();
+	camv_dlg_viewport_uninit();
 }
 
 int pplg_init_dialogs(void)
@@ -88,8 +98,10 @@ int pplg_init_dialogs(void)
 
 	RND_REGISTER_ACTIONS(camv_dialogs_action_list, camv_dialogs_cookie);
 	rnd_dlg_pref_init(camv_dlg_pref_tab, camv_dlg_pref_first_init);
+	camv_dlg_viewport_init();
 
 	rnd_event_bind(CAMV_EVENT_LAYERS_CHANGED, camv_dialogs_layer_chg_ev, NULL, camv_dialogs_cookie);
+	rnd_event_bind(CAMV_EVENT_LAYERVIS_CHANGED, camv_dialogs_layervis_chg_ev, NULL, camv_dialogs_cookie);
 	rnd_event_bind(CAMV_EVENT_LAYER_SELECTED, camv_dialogs_layer_selected_ev, NULL, camv_dialogs_cookie);
 
 	return 0;
