@@ -2,5 +2,5 @@ extern const char camv_acts_LayerDialog[];
 extern const char camv_acth_LayerDialog[];
 fgw_error_t camv_act_LayerDialog(fgw_arg_t *res, int argc, fgw_arg_t *argv);
 
-void camv_layer_dlg_layer_chg_ev(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[]);
+void camv_layer_dlg_layer_chg_ev(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[]);
 
