@@ -1,7 +1,7 @@
  /*
   *                            COPYRIGHT
   *
-  *  pcb-rnd, interactive printed circuit board design
+  *  camv-rnd - electronics-related CAM viewer
   *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
   *
   *  This program is free software; you can redistribute it and/or modify
@@ -19,15 +19,15 @@
   *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Contact:
-  *    Project page: http://repo.hu/projects/pcb-rnd
-  *    lead developer: http://repo.hu/projects/pcb-rnd/contact.html
+  *    Project page: http://repo.hu/projects/camv-rnd
+  *    lead developer: http://repo.hu/projects/camv-rnd/contact.html
   *    mailing list: pcb-rnd (at) list.repo.hu (send "subscribe")
   */
 
 #include <librnd/config.h>
 
 #include <stdio.h>
-#include <librnd/core/hid.h>
+#include <librnd/hid/hid.h>
 #include <librnd/plugins/lib_exp_text/lpr_hid.h>
 
 #include "../export_ps/export_ps.h"
