@@ -53,8 +53,8 @@ Scale output to make the sheet fit the page.
 @end ftable
 %end-doc
 */
-	{"fill-page", "Scale drawing to fill page (default on)",
-	 RND_HATT_BOOL, 0, 0, {1, 0, 0}, 0},
+	{"fill-page", "Scale drawing to fill page (default off)",
+	 RND_HATT_BOOL, 0, 0, {0, 0, 0}, 0},
 #define HA_fillpage 1
 
 /* %start-doc options "91 Postscript Export"
