@@ -91,7 +91,7 @@ static void emit_build(rnd_pline_t *pl, void *ud)
 }
 
 /* Returns a polygon or a group of polygons, free's src*/
-static camv_any_obj_t *polyarea2camv(rnd_polyarea_t *src)
+static camv_any_obj_t *polyarea2camv(gedraw_ctx_t *ctx, rnd_polyarea_t *src)
 {
 	rnd_pline_t *l;
 	long holes = 0, islands = 0;
@@ -107,6 +107,7 @@ static camv_any_obj_t *polyarea2camv(rnd_polyarea_t *src)
 	if (holes > 0) { /* has holes, dice and return a group of objects */
 		camv_grp_t *grp = camv_grp_new();
 		grp->len = 0;
+		grp->loc.line = ctx->line; grp->loc.col = ctx->col;
 		grp->objs = calloc(sizeof(camv_any_obj_t), (holes+2)*2);
 		rnd_polyarea_no_holes_dicer(src, 0, 0, 0, 0, emit_build, grp); /* handles islands */
 		return (camv_any_obj_t *)grp;
@@ -116,6 +117,7 @@ static camv_any_obj_t *polyarea2camv(rnd_polyarea_t *src)
 			long i = 0;
 			camv_grp_t *grp = camv_grp_new();
 
+			grp->loc.line = ctx->line; grp->loc.col = ctx->col;
 			grp->len = islands;
 			grp->objs = malloc(sizeof(camv_any_obj_t) * grp->len);
 			pa = src;
@@ -131,6 +133,7 @@ static camv_any_obj_t *polyarea2camv(rnd_polyarea_t *src)
 		}
 		else { /* single island, no holes: return a sinlge camv poly */
 			camv_poly_t *dst = camv_poly_new();
+			dst->loc.line = ctx->line; dst->loc.col = ctx->col;
 			pline2camv(dst, src->contours);
 			rnd_polyarea_free(&src);
 			return (camv_any_obj_t *)dst;
@@ -139,7 +142,7 @@ static camv_any_obj_t *polyarea2camv(rnd_polyarea_t *src)
 }
 
 /* Convert an oblong aperture into a camv polygon around 0;0 */
-static camv_any_obj_t *aper_oblong2poly(ge_aper_t *aper, double rot)
+static camv_any_obj_t *aper_oblong2poly(gedraw_ctx_t *ctx, ge_aper_t *aper, double rot)
 {
 	rnd_coord_t xs = aper->data.oblong.xs, ys = aper->data.oblong.ys, xh, yh;
 	rnd_polyarea_t *pa, *ph, *ptmp;
@@ -166,18 +169,19 @@ static camv_any_obj_t *aper_oblong2poly(ge_aper_t *aper, double rot)
 		pa = ptmp;
 	}
 
-	o = polyarea2camv(pa);
+	o = polyarea2camv(ctx, pa);
 	return o;
 }
 
 /* Convert a regular polygon with no hole aperture into a camv polygon around 0;0 */
-static camv_any_obj_t *aper_poly2poly_nohole(ge_aper_t *aper, double rot)
+static camv_any_obj_t *aper_poly2poly_nohole(gedraw_ctx_t *ctx, ge_aper_t *aper, double rot)
 {
 	camv_any_obj_t *o;
 	double r, a, as;
 	int n;
 
 	o = (camv_any_obj_t *)camv_poly_new();
+	o->proto.loc.line = ctx->line; o->proto.loc.col = ctx->col;
 	camv_poly_allocpts(&o->poly, aper->data.poly.corners);
 	as = (360.0 / (double)aper->data.poly.corners) / RND_RAD_TO_DEG;
 	r = (double)aper->data.poly.dia / 2.0;
@@ -211,7 +215,7 @@ static rnd_polyarea_t *pa_regpoly(rnd_coord_t cx, rnd_coord_t cy, rnd_cardinal_t
 }
 
 /* Convert a regular polygon with hole aperture into a camv polygon around 0;0 */
-static camv_any_obj_t *aper_poly2poly_hole(ge_aper_t *aper, double rot)
+static camv_any_obj_t *aper_poly2poly_hole(gedraw_ctx_t *ctx, ge_aper_t *aper, double rot)
 {
 	rnd_polyarea_t *ps, *ph, *pres;
 
@@ -219,7 +223,7 @@ static camv_any_obj_t *aper_poly2poly_hole(ge_aper_t *aper, double rot)
 	ph = rnd_poly_from_circle(0, 0, aper->hole/2);
 	rnd_polyarea_boolean_free(ps, ph, &pres, RND_PBO_SUB);
 
-	return polyarea2camv(pres);
+	return polyarea2camv(ctx, pres);
 }
 
 /* idx is counted from 1 for code clarity */
@@ -525,7 +529,7 @@ static camv_any_obj_t *aper_macro_render(ge_aper_t *aper, gedraw_ctx_t *ctx, dou
 		rnd_message(RND_MSG_WARNING, "aperture macro results in empty render\n");
 		return NULL;
 	}
-	return polyarea2camv(pa);
+	return polyarea2camv(ctx, pa);
 }
 
 
@@ -538,6 +542,7 @@ static camv_any_obj_t *gedraw_render_aper_nohole(camv_design_t *camv, gedraw_ctx
 	switch(aper->shape) {
 		case GEA_CIRC:
 			o = (camv_any_obj_t *)camv_line_new();
+			o->proto.loc.line = ctx->line; o->proto.loc.col = ctx->col;
 			o->line.x1 = o->line.x2 = ox;
 			o->line.y1 = o->line.y2 = oy;
 			o->line.thick = aper->data.circ.dia;
@@ -545,6 +550,7 @@ static camv_any_obj_t *gedraw_render_aper_nohole(camv_design_t *camv, gedraw_ctx
 
 		case GEA_RECT:
 			o = (camv_any_obj_t *)camv_poly_new();
+			o->proto.loc.line = ctx->line; o->proto.loc.col = ctx->col;
 			camv_poly_allocpts(&o->poly, 4);
 
 			rx = ((double)aper->data.rect.xs / 2.0);
@@ -568,14 +574,14 @@ static camv_any_obj_t *gedraw_render_aper_nohole(camv_design_t *camv, gedraw_ctx
 
 		case GEA_OBLONG:
 			if (aper->cached == NULL)
-				aper->cached = aper_oblong2poly(aper, rot);
+				aper->cached = aper_oblong2poly(ctx, aper, rot);
 			o = camv_obj_dup(aper->cached);
 			o->proto.calls->move(o, ox, oy);
 			return o;
 
 		case GEA_POLY:
 			if (aper->cached == NULL)
-				aper->cached = aper_poly2poly_nohole(aper, rot);
+				aper->cached = aper_poly2poly_nohole(ctx, aper, rot);
 			o = camv_obj_dup(aper->cached);
 			o->proto.calls->move(o, ox, oy);
 			return o;
@@ -605,7 +611,7 @@ TODO("Generate and cache these and dup with offset instead of reconstructing all
 				ps = rnd_poly_from_circle(0, 0, aper->data.circ.dia/2);
 				ph = rnd_poly_from_circle(0, 0, aper->hole/2);
 				rnd_polyarea_boolean_free(ps, ph, &pdiff, RND_PBO_SUB);
-				aper->cached = polyarea2camv(pdiff);
+				aper->cached = polyarea2camv(ctx, pdiff);
 			}
 			o = camv_obj_dup(aper->cached);
 			o->proto.calls->move(o, ox, oy);
@@ -619,7 +625,7 @@ TODO("Generate and cache these and dup with offset instead of reconstructing all
 				ps = rnd_poly_from_rect(-rx, +rx, -ry, +ry);
 				ph = rnd_poly_from_circle(0, 0, aper->hole/2);
 				rnd_polyarea_boolean_free(ps, ph, &pdiff, RND_PBO_SUB);
-				aper->cached = polyarea2camv(pdiff);
+				aper->cached = polyarea2camv(ctx, pdiff);
 			}
 			o = camv_obj_dup(aper->cached);
 			o->proto.calls->move(o, ox, oy);
@@ -627,14 +633,14 @@ TODO("Generate and cache these and dup with offset instead of reconstructing all
 
 		case GEA_OBLONG:
 			if (aper->cached == NULL)
-				aper->cached = aper_oblong2poly(aper, rot); /* handles the hole */
+				aper->cached = aper_oblong2poly(ctx, aper, rot); /* handles the hole */
 			o = camv_obj_dup(aper->cached);
 			o->proto.calls->move(o, ox, oy);
 			return o;
 
 		case GEA_POLY:
 			if (aper->cached == NULL)
-				aper->cached = aper_poly2poly_hole(aper, rot);
+				aper->cached = aper_poly2poly_hole(ctx, aper, rot);
 			o = camv_obj_dup(aper->cached);
 			o->proto.calls->move(o, ox, oy);
 			return o;
@@ -716,6 +722,7 @@ static void gedraw_poly_close(camv_design_t *camv, gedraw_ctx_t *ctx, camv_layer
 		rnd_message(RND_MSG_ERROR, "gedraw_poly_close: contour is not closed\n");
 
 	o = (camv_any_obj_t *)camv_poly_new();
+	o->proto.loc.line = ctx->line; o->proto.loc.col = ctx->col;
 	camv_poly_allocpts(&o->poly, ctx->contour.used/2);
 	for(n = 0, i = 0; i < ctx->contour.used; n++) {
 		o->poly.x[n] = ctx->contour.array[i++];
@@ -808,6 +815,7 @@ static void gedraw_do_draw_line(camv_design_t *camv, gedraw_ctx_t *ctx, camv_lay
 	switch(aper->shape) {
 		case GEA_CIRC:
 			o = (camv_any_obj_t *)camv_line_new();
+			o->proto.loc.line = ctx->line; o->proto.loc.col = ctx->col;
 			o->line.x1 = ctx->ox + last->x; o->line.y1 = ctx->oy + last->y;
 			o->line.x2 = ctx->ox + curr->x; o->line.y2 = ctx->oy + curr->y;
 			o->line.thick = aper->data.circ.dia;
@@ -826,6 +834,7 @@ static void gedraw_do_draw_line(camv_design_t *camv, gedraw_ctx_t *ctx, camv_lay
 				y2 = MAX(last->y, curr->y);
 
 				o = (camv_any_obj_t *)camv_poly_new();
+				o->proto.loc.line = ctx->line; o->proto.loc.col = ctx->col;
 				camv_poly_allocpts(&o->poly, 4);
 				o->poly.x[0] = rnd_round(ctx->ox + x1 - rx);
 				o->poly.y[0] = rnd_round(ctx->oy + y1 - ry);
@@ -854,7 +863,7 @@ static void gedraw_do_draw_line(camv_design_t *camv, gedraw_ctx_t *ctx, camv_lay
 				slice = pa_rect_side(last, curr, ctx->ox-rx, ctx->oy-ry, ctx->ox-rx, ctx->oy+ry); /* left vert */
 				rnd_polyarea_boolean_free(sum, slice, &pres, RND_PBO_UNITE); sum = pres;
 
-				o = polyarea2camv(sum);
+				o = polyarea2camv(ctx, sum);
 				camv_obj_add_to_layer(ly, o);
 			}
 			break;
@@ -975,6 +984,7 @@ static void gedraw_do_draw_arc(camv_design_t *camv, gedraw_ctx_t *ctx, camv_laye
 	}
 
 	arc = camv_arc_new();
+	arc->loc.line = ctx->line; arc->loc.col = ctx->col;
 	arc->cx = ctx->ox + cx; arc->cy = ctx->oy + cy; arc->r = r1;
 	arc->thick = aper == NULL ? 0 : aper->data.circ.dia;
 	arc->start = 180 - ang1;
@@ -989,6 +999,7 @@ static void gedraw_do_draw(camv_design_t *camv, gedraw_ctx_t *ctx, camv_layer_t
 		case GEI_CW:  gedraw_do_draw_arc(camv, ctx, ly, curr, last, 1); break;
 		case GEI_CCW: gedraw_do_draw_arc(camv, ctx, ly, curr, last, 0); break;
 	}
+	curr->i = curr->j = 0;
 }
 
 static void gedraw_do_move(camv_design_t *camv, gedraw_ctx_t *ctx, camv_layer_t *ly, gerbst_t *curr, gerbst_t *last)
@@ -1047,6 +1058,7 @@ static int gedraw_camv_(camv_design_t *camv, gedraw_ctx_t *ctx, const camv_layer
 
 	for(n = *from; n < ctx->code.used; n++) {
 		gedraw_inst_t *i = &ctx->code.array[n]; /* need to retrieve it each iteration because n may jump after SR */
+		ctx->line = i->line; ctx->col = i->col;
 		switch(i->cmd) {
 			case GEC_MACRO_DEF:  break; /* shouldn't happen */
 
@@ -1152,6 +1164,7 @@ static int gedraw_camv(camv_design_t *camv, gedraw_ctx_t *ctx, const char *name)
 	size_t from = 0;
 	camv_layer_t *ly = camv_layer_new();
 	gerbst_t curr, last;
+	int res;
 
 	ly->name = rnd_strdup(name);
 	camv_layer_invent_color(camv, ly); /* gerber files do not have layer color */
@@ -1162,7 +1175,9 @@ static int gedraw_camv(camv_design_t *camv, gedraw_ctx_t *ctx, const char *name)
 	curr.quadr = GEQ_INVALID;
 	memcpy(&last, &curr, sizeof(last));
 
-	return gedraw_camv_(camv, ctx, ly, &ly, &from, 0, &curr, &last);
+	res = gedraw_camv_(camv, ctx, ly, &ly, &from, 0, &curr, &last);
+	ctx->line = ctx->col = -1;
+	return res;
 }
 
 static int ge_getchar(geparse_ctx_t *ctx)
