@@ -5,7 +5,7 @@
 
 #include <librnd/core/global_typedefs.h>
 #include <librnd/core/hidlib.h>
-#include <librnd/core/tool.h>
+#include <librnd/hid/tool.h>
 
 static const char std_tools_cookie[] = "std_tools";
 
