@@ -11,6 +11,7 @@
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/misc_util.h>
 #include <librnd/core/rnd_conf.h>
+#include <math.h>
 
 camv_tool_mline_t camv_tool_mline;
 
@@ -20,6 +21,7 @@ static void create_mline(rnd_design_t *hl)
 	camv_design_t *camv = (camv_design_t *)hl;
 	camv_layer_t *ly = camv_layer_by_name(camv, camv_measurement_layer_name, 1);
 	double dist = rnd_distance(camv_tool_mline.x1, camv_tool_mline.y1, camv_tool_mline.x2, camv_tool_mline.y2);
+	double scale;
 
 	o = (camv_any_obj_t *)camv_line_new();
 	o->line.x1 = camv_tool_mline.x1; o->line.y1 = camv_tool_mline.y1;
@@ -33,6 +35,21 @@ static void create_mline(rnd_design_t *hl)
 	o->text.rot = atan2(camv_tool_mline.y2 - camv_tool_mline.y1, camv_tool_mline.x2 - camv_tool_mline.x1) * RND_RAD_TO_DEG;
 	o->text.s = rnd_strdup_printf("%m+%.03$$mS", rnd_conf.editor.grid_unit->allow, (rnd_coord_t)dist);
 
+	scale = log(dist/1000000.0);
+	if (scale < 0) {
+		scale = floor(dist/100000.0) / 100.0;
+		if (scale < 0.0025)
+			scale = 0.0025;
+	}
+	else if (scale < 1)
+		scale = floor(scale)*0.8+0.2;
+	else
+		scale = floor(scale);
+
+	o->text.scale = scale;
+	o->text.thickness = scale/20.0;
+
+
 	camv_text_update(hl, &o->text, ly);
 	camv_obj_add_to_layer(ly, o);
 }
